/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.sling.cms.core.publication;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;
import static org.junit.Assert.fail;

import java.util.HashMap;
import java.util.Map;

import org.apache.sling.cms.core.helpers.SlingCMSTestHelper;
import org.apache.sling.cms.publication.PUBLICATION_MODE;
import org.apache.sling.cms.publication.PublicationManagerFactory;
import org.apache.sling.distribution.Distributor;
import org.apache.sling.testing.mock.sling.junit.SlingContext;
import org.junit.Before;
import org.junit.Rule;
import org.junit.Test;
import org.mockito.Mockito;
import org.osgi.service.component.ComponentException;

public class PublicationManagerFactoryImplTest {

    @Rule
    public final SlingContext context = new SlingContext();

    @Before
    public void init() {
        SlingCMSTestHelper.initContext(context);
    }

    @Test
    public void testStandalone() {
        Map<String, Object> properties = new HashMap<>();
        properties.put("publicationMode", "STANDALONE");
        PublicationManagerFactory factory = context.registerInjectActivateService(new PublicationManagerFactoryImpl(),
                properties);
        assertEquals(PUBLICATION_MODE.STANDALONE, factory.getPublicationMode());
        assertTrue(factory.getPublicationManager() instanceof StandalonePublicationManager);
    }

    @Test
    public void testInvalidContentDistribution() {
        Map<String, Object> properties = new HashMap<>();
        properties.put("publicationMode", "CONTENT_DISTRIBUTION");
        PublicationManagerFactory factory = context.registerInjectActivateService(new PublicationManagerFactoryImpl(),
                properties);
        assertEquals(PUBLICATION_MODE.CONTENT_DISTRIBUTION, factory.getPublicationMode());
        try {
            factory.getPublicationManager();
            fail();
        } catch (ComponentException e) {
            // expected to fail
        }
    }

    @Test
    public void testValidContentDistribution() {
        Map<String, Object> properties = new HashMap<>();
        properties.put("publicationMode", "CONTENT_DISTRIBUTION");
        context.registerService(Distributor.class, Mockito.mock(Distributor.class));
        PublicationManagerFactory factory = context.registerInjectActivateService(new PublicationManagerFactoryImpl(),
                properties);
        assertEquals(PUBLICATION_MODE.CONTENT_DISTRIBUTION, factory.getPublicationMode());
        assertTrue(factory.getPublicationManager() instanceof ContentDistributionPublicationManager);
    }

}